@@ -1,4 +1,4 @@
-package Algorithm::CheckDigits::M10_009;
+package Algorithm::CheckDigits::M10_008;
 
 use 5.006;
 use strict;
@@ -24,6 +24,8 @@ our @EXPORT_OK = ( 'new', @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
 
+my @weight = ( 1,3,1,7,3,9,1 );
+
 sub new {
 	my $proto = shift;
 	my $type  = shift;
@@ -35,16 +37,15 @@ sub new {
 
 sub is_valid {
 	my ($self,$number) = @_;
-	if ($number =~ /^([0-9 ]*)([0-9])$/) {
-		my $cd = $self->_compute_checkdigit($1);
-		return ($2 == $cd || $2 == ((5 + $cd) % 10));
+	if ($number =~ /^(\d{6})(\d)$/) {
+		return $2 == $self->_compute_checkdigit($1);
 	}
 	return ''
 } # is_valid()
 
 sub complete {
 	my ($self,$number) = @_;
-	if ($number =~ /^[0-9 ]*$/) {
+	if ($number =~ /^\d{6}$/) {
 		return  $number . $self->_compute_checkdigit($number);
 	}
 	return '';
@@ -52,16 +53,16 @@ sub complete {
 
 sub basenumber {
 	my ($self,$number) = @_;
-	if ($number =~ /^([0-9 ]*)([0-9])$/) {
-		return $1 if ($self->is_valid($number));
+	if ($number =~ /^(\d{6})(\d)$/) {
+		return $1 if ($2 == $self->_compute_checkdigit($1));
 	}
 	return '';
 } # basenumber()
 
 sub checkdigit {
 	my ($self,$number) = @_;
-	if ($number =~ /^([0-9 ]*)([0-9])$/) {
-		return $2 if ($self->is_valid($number));
+	if ($number =~ /^(\d{6})(\d)$/) {
+		return $2 if ($2 == $self->_compute_checkdigit($1));
 	}
 	return '';
 } # checkdigit()
@@ -69,21 +70,18 @@ sub checkdigit {
 sub _compute_checkdigit {
 	my $self   = shift;
 	my $number = shift;
-	$number =~ s/\s//g;
-	if ($number =~ /^([0-9]*)$/) {
+
+	if ($number =~ /^\d{6}$/) {
+
 		my @digits = split(//,$number);
-		my $even = 0;
-		my $sum  = 0;
+		my $sum    = 0;
+
 		for (my $i = 0; $i <= $#digits; $i++) {
-			if ($even) {
-				my $tmp = 2 * $digits[$i];
-				$sum += $tmp / 10 + $tmp % 10;
-			} else {
-				$sum += $digits[$i];
-			}
-			$even = not $even;
+
+			$sum += $weight[$i] * $digits[$i];
+
 		}
-		return $sum % 10;
+		return (10 - ($sum % 10) % 10);
 	}
 	return -1;
 } # _compute_checkdigit()
@@ -95,26 +93,26 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M10_009 - compute check digits for Betriebsnummer (DE)
+CheckDigits::M10_008 - compute check digits for Sedol (GB)
 
 =head1 SYNOPSIS
 
   use CheckDigits;
 
-  $betrnr = CheckDigits('betriebsnummer');
+  $sedol = CheckDigits('sedol');
 
-  if ($betrnr->is_valid('73282932000074')) {
+  if ($sedol->is_valid('0123457')) {
 	# do something
   }
 
-  $cn = $betrnr->complete('7328293200007');
-  # $cn = '73282932000074'
+  $cn = $sedol->complete('012345');
+  # $cn = '0123457'
 
-  $cd = $betrnr->checkdigit('73282932000074');
-  # $cd = '4'
+  $cd = $sedol->checkdigit('0123457');
+  # $cd = '7'
 
-  $bn = $betrnr->basenumber('73282932000074');
-  # $bn = '7328293200007'
+  $bn = $sedol->basenumber('0123457');
+  # $bn = '012345'
   
 =head1 DESCRIPTION
 
@@ -124,23 +122,17 @@ CheckDigits::M10_009 - compute check digits for Betriebsnummer (DE)
 
 =item 1
 
-Beginning left all numbers are weighted alternatively 1 and 2.
+Beginning left all numbers are weighted with 1,3,1,7,3,9 and 1
+(checkdigit)
 
 =item 2
 
-The total of the digits of all products is computed.
+The sum of all products is computed.
 
 =item 3
 
-The sum of step 3 ist taken modulo 10.
-
-=item 4
-
-The check digit is the difference between 10 and the number from step
-3 taken modulo 10.
-
-HINT: The last digit of the 'Betriebsnummer' may be the check digit or
-the last digit of the sum of the constant 5 and the check digit.
+The check digit is the difference of the sum from step 3 to the next
+multiple of 10.
 
 =back
 
@@ -192,6 +184,5 @@ Mathias Weidner, E<lt>mathias@weidner.in-bad-schmiedeberg.deE<gt>
 L<perl>,
 L<CheckDigits>,
 F<www.pruefziffernberechnung.de>.
-F<www.dsi.cnrs.fr/bureau_qualite/admindonnees/documents/siren.pdf>
 
 =cut
